@@ -3,6 +3,10 @@
 
 ## }
 
+## if(!exists("rep_len", mode = "function")) # old R version
+##     rep_len <- function(x, length.out) rep(x, length.out=length.out)
+
+
 .set.eps_view <- function() {
     ## This assumes  "gv"  in your path --- ideally this would be configured!
     if(!is.character(getOption("eps_view")) && .Platform $ OS.type == "unix") {
@@ -35,18 +39,3 @@
 	options("eps_view" = cmd)
     }
 }
-
-## was	.First.lib <- function(lib, pkg) { .. }
-
-## no longer used, now we require R >= 2.5.0  but keep as placeholder:
-if(getRversion() < "2.5") {
-
-    ## note that this remains hidden in "sfsmisc" namespace
-    parse <- function (file = "", n = NULL, text = NULL, prompt = "?",
-		       srcfile = NULL, encoding = "unknown")
-    {
-	## just drop 'srcfile' and 'encoding'
-	base::parse(file, n=n, text=text, prompt=prompt)
-    }
-
-}
